| enrichwrapper | R Documentation |
Annotate the function of the cell-type-specific differential DNA methylation
probes called from celldiff.
enrichwrapper(
sigprobes,
celltype,
pairedRNA = NULL,
pairedmethyl = NULL,
abscut = 0.6,
generegions = c("TSS200"),
platform = "450K",
uniquegenes = TRUE,
dbs = c("GO_Biological_Process_2018", "BioPlanet_2019", "Reactome_2016"),
write = FALSE
)
sigprobes |
The list result returned by |
celltype |
The cell type whose differential methylation probes needs to be annotated. Should be a string of the cell type name. |
pairedRNA |
The RNA part of the paired RNA-DNA methylation dataset. If
both this parameter and |
pairedmethyl |
The methylation part of the paired RNA-DNA methylation
dataset. If both this parameter and |
abscut |
When the correlation method is used to select the genes with a significant correlation to the cell-type-specific differential probes, the ones with an absolute Pearson correlation coefficient value greater than this parameter value will be selected and used for function analysis. The default value is 0.6. |
generegions |
When the function analysis is directly performed on the
genes mapped from the differential methylated probes, if a probe located
in the regions defined by this parameter, its corresponding gene will be
used for the function analysis. Default is "TSS200", so that only probes
within TSS200 regions will be used for gene mapping, and it can also be a
vector, such as |
platform |
A string indicating the platform of the differential probes
recorded in |
uniquegenes |
A logical value and if this parameter is set as TRUE,
after getting the genes for function analysis from the cell type indicated
by |
dbs |
The databases for gene function enrichment analysis. Default is
|
write |
A logical value indicating whether the gene function results need to be written into txt files in the working directory. The default value is FALSE. |
A list with four slots recording the gene annotation and function
enrichment results for the enhanced and inhibited genes (when correlation-
based method is used) or for the genes mapped from the hypomethylated and
hypermethylated probes (when correlation-based method is not used), and if
write is TRUE, txt files will be made to save these results.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.