| epDeconv | R Documentation |
Deconvolve bulk DNA methylation data with RNA reference and also by a paired bulk RNA-bulk DNA methylation dataset
epDeconv(
rnaref = NULL,
Seuratobj = NULL,
targetcelltypes = NULL,
celltypecolname = "annotation",
samplebalance = FALSE,
pseudobulkdat = NULL,
geneversion = "hg19",
genekey = "SYMBOL",
manualmarkerlist = NULL,
rnamat,
methylmat,
learnernum = 10,
rnamatlogged,
resscale = FALSE,
threads = 1,
lassoerrortype = "min",
targetmethyldat = NULL,
plot = FALSE,
pddat = NULL,
targetmethylpddat = NULL
)
rnaref |
The RNA reference recording the signature of each cell type.
Each row is one gene, and each column is one cell type. Each entry should
be a gene TPM value. Column names are cell type names and row names are
gene names. The default is NULL and in this case, it can be synthesized
from the scRNA-seq data transferred to the parameter |
Seuratobj |
An object of class Seurat generated with the |
targetcelltypes |
When use |
celltypecolname |
When use |
samplebalance |
When use |
pseudobulkdat |
If the scRNA-seq data transferred via |
geneversion |
To calculate the TPM value of the genes when generating the reference matrix, the effective length of the genes will be needed. This parameter is used to define from which genome version the effective gene length will be extracted. For human genes, "hg19" or "hg38" can be used, for mouse, "mm10" can be used. Default is "hg19". |
genekey |
The type of the gene IDs used in the |
manualmarkerlist |
During making the reference matrix from scRNA-seq data, for each cell type, the genes specially expressed in it with a high level will be deemed as markers and used to generate the reference, but it cannot be ensured that some known classical markers can be selected, and so if want to make sure these markers can be used for the reference, a list can be used as an input to this parameter, with its element names as the cell type names and the elements as vectors with the gene IDs of these classical markers. It should be noted that before the final reference is determined, all the marker genes need to go through several filter steps, such as extremely highly expressed genes and colinearity contributing genes removal, to improve the reference quality, so that the classical genes provided via this parameter will be definitely used for reference generation, but may also be filtered out before the final one is made. The default value of this parameter is NULL. |
rnamat |
The RNA data of the paired bulk RNA-bulk methylation dataset.
Its sample cell contents will be first deconvolved via the RNA reference
provided to the parameter |
methylmat |
The DNA methylaiton data of the paired bulk RNA-bulk DNA
methylaiton dataset. Should be a matrix with each column representing a
sample and each row representing a feature. Row names are feature names
and column names are sample IDs. The sample IDs should be the same as the
ones in |
rnamatlogged |
A logical value indicating whether the gene values in
|
resscale |
For each sample, whether its cell contents result should be scaled so that the sum of different cell types is 1. Default is FALSE. |
threads |
Number of threads need to be used to do the computation. Its default value is 1. |
lassoerrortype |
The base learners of the bagging model to deconvolve the DNA methylation data are LASSO models and the lambda value for each of them (regularization coefficient) is selected from a grid search. This parameter is used to determine whether the lambda value should be the one giving the minimum cross-validation error (set it as "min"), or the one giving an error within 1 standard error of the minimum (set it as "1se"). Default is "min". |
targetmethyldat |
The target cell mixture methylation data need to be
deconvolved. Should be a matrix with each column representing one sample
and each row for one feature. Row names are feature names and column names
are sample IDs. It is recommended to adjust the batch difference between
this dataset and |
plot |
Whether generate box plots, heatmaps, and scatter plots for the deconvolution results for the paired RNA data, paired methylaiton data, and target methylation data. Default is FALSE. |
pddat |
If set |
targetmethylpddat |
If |
leanernum |
The base leaner number for the bagging model to deconvolve DNA methylation data. Default is 10. |
A list containing several slots recording the deconvolution results
for the paired RNA and paired DNA methylation data (slots "rnacellconts"
and "methylcellconts"), the base leaners of the cell deconvolution model
(slots "modellist" and "modelcoeflist"), the weights of the base learners
(slots "normweights" and "weights"), the gene subsets used by each RNA
data deconvolution base learner (slot "rnageneidxlist"), and the paired
RNA-methylation sample cell contents correlation (expressed as R square)
deconvolved by each base learner (slot "rnamethylsqrs"). If the target DNA
methylation data is provided to the parameter targetmethyldat, a
slot recording its cell contents result predicted by the model will also
be returned (slot "methyltargetcellcounts").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.