| methylpredict | R Documentation |
Predict cell contents for new methylation data with the model trained from
the function epDeconv.
methylpredict(
model = NULL,
normweights = NULL,
modellist = NULL,
targetmethyldat,
resscale = FALSE,
adjustminus = FALSE
)
model |
Result returned from the function |
modellist |
The slot "modellist" of the result of |
targetmethyldat |
The target cell mixture methylation data need to be
deconvolved. Should be a matrix with each column representing one sample
and each row for one feature. Row names are feature names and column names
are sample IDs. It is recommended to adjust the batch difference between
this dataset and the paired methylation data used by |
resscale |
For each sample, whether its cell contents result should be scaled so that the sum of different cell types is 1. Default is FALSE. |
adjustminus |
In some extreme situations, the cell contents predicted may be minus values and this parameter indicates whether these minus ones should be changed to 0 in the final result. Default is FALSE. |
normweight |
The slot "normweigth" of the result of |
A matrix recording the cell composition result for the samples.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.