| refDeconv | R Documentation |
Deconvolve cell contents using reference from the same omics.
refDeconv(
ref,
targetdat,
targetlogged = FALSE,
resscale = FALSE,
plot = FALSE,
pddat = NULL,
threads = 1
)
ref |
The reference matrix recording the signature of each cell type. Each row represents one feature, and each column is one cell type. Each entry should be a non-log transformed value, such as TPM value for RNA data, and beta value for DNA methylation data. Column names are cell type names and row names are feature names. |
targetdat |
The target cell mixture data need to be deconvolved. Should
be a matrix with each column representing one sample and each row for one
feature. Row names are feature names and column names are sample IDs. If
the reference matrix is generated with the function |
targetlogged |
Whether the feature values in |
resscale |
For each sample, whether its cell contents result should be scaled so that the sum of different cell types is 1. Default is FALSE. |
plot |
Whether generate a box plot and heatmaps for the cell contents deconvolved. Default is FALSE. |
pddat |
If set |
threads |
Number of threads need to be used to do the computation. Its default value is 1. |
A matrix recording the cell composition result for the samples.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.