| scDeconv | R Documentation |
Deconvolve bulk RNA-seq or bulk RNA microarray data using scRNA-seq data.
scDeconv(
Seuratobj,
targetcelltypes = NULL,
celltypecolname = "annotation",
samplebalance = FALSE,
pseudobulkdat = NULL,
geneversion = "hg19",
genekey = "SYMBOL",
targetdat = NULL,
targetlogged = FALSE,
manualmarkerlist = NULL,
markerremovecutoff = 0.6,
minrefgenenum = 500,
saveref = FALSE,
refcutoff = 0.95,
refadjustcutoff = 0.4,
resscale = FALSE,
plot = FALSE,
pddat = NULL,
threads = 1
)
Seuratobj |
An object of class Seurat generated with the |
targetcelltypes |
The cell types whose content need to be deconvolved.
If NULL, all the cell types included in |
celltypecolname |
In the "meta.data" slot of |
samplebalance |
At the beginning of making the cell reference matrix,
the scRNA-seq cell counts contained in |
pseudobulkdat |
If the scRNA-seq data transferred via |
geneversion |
To calculate the TPM value of the genes in the reference matrix, the effective length of the genes will be needed. This parameter is used to define from which genome version the effective gene length will be extracted. For human genes, "hg19" or "hg38" can be used, for mouse, "mm10" can be used. Default is "hg19". |
genekey |
The type of the gene IDs used in the |
targetdat |
The target cell mixture gene expression data need to be
deconvolved. Should be a matrix with each column representing one sample
and each row representing one gene. The gene ID type here should be the
same as that transferred to the parameter |
targetlogged |
Whether the gene expression values in |
manualmarkerlist |
During making the reference matrix from scRNA-seq data, for each cell type, the genes specially expressed in it with a high level will be deemed as markers and used to generate the reference, but it cannot be ensured that some known classical markers can be selected, and so if want to make sure these markers can be used for the reference, a list can be used as an input to this parameter, with its element names as the cell type names and the elements as vectors with the gene IDs of these classical markers. It should be noted that before the final reference is determined, all the marker genes need to go through several filter steps, such as extremely highly expressed genes and collinearity contributing genes removal, to improve the reference quality, so that the classical genes provided via this parameter will be definitely used for reference generation, but may also be filtered out before the final one is made. The default value of this parameter is NULL. |
markerremovecutoff |
During the reference matrix generation from the
scRNA-seq data, the gene expression values in the |
minrefgenenum |
Because the genes to generate the reference matrix need to go through several filter steps and in some cases, only a small number of them can fulfill all the filter conditions, which makes the gene number in the reference is very small and then influences the next deconvolution. To avoid this extreme case, a cutoff for the reference gene number need to be defined here, so that once the gene number in the reference has been filtered to this level, the filter process will be ended to guarantee the gene number of the reference. This parameter is used to set this cutoff, and its default value is 500. |
saveref |
Whether need to save the finally generated reference matrix, and the adjusted cell mixture matrix to be deconvolved as rds files in the working directory automatically. Default is FALSE. |
refcutoff |
To improve the robustness of the deconvolution result, some extremely highly expressed genes in the reference need to be filtered out due to their large variance. This cutoff is used to set the percent of genes can be kept in the reference while the other genes with a higher expression level will be filtered. The default value is 0.95, meaning the top 5% most highly expressed genes will be removed from the reference. |
refadjustcutoff |
For some similar cell types, their gene expressions in the reference matrix are highly correlated, which makes the downstream deconvolution difficult. To relive this problem, for each similar cell pair, some genes largely contributing to their correlation will be found and removed, so that their correlation in the reference can be reduced. This parameter is used to set the cutoff of the cell pair correlation, and if a cell pair has a Pearson correlation coefficient greater than it, the contributing gene filter process will be used to reduce the coefficient until it becomes smaller than this value. The default is 0.4. |
resscale |
For each sample, whether its cell contents result should be scaled so that the sum of different cell types is 1. Default is FALSE. |
plot |
Whether generate a box plot and heatmaps for the cell contents deconvolved. Default is FALSE. |
pddat |
If set |
threads |
Number of threads need to be used to do the computation. Its default value is 1. |
A list containing the generated RNA reference, the adjusted target data to be deconvolved, and the cell deconvolution result for the samples. The gene values in the adjusted target data are non-log transformed ones.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.